pub struct ExpandedSchema {
pub entities: Vec<ExpandedEntity>,
pub json_structures: Vec<ExpandedJsonStructure>,
pub relations: Vec<ExpandedRelation>,
pub classifications: Vec<ExpandedClassification>,
}Fields
entities: Vec<ExpandedEntity>json_structures: Vec<ExpandedJsonStructure>relations: Vec<ExpandedRelation>classifications: Vec<ExpandedClassification>Trait Implementations
Sourceimpl Clone for ExpandedSchema
impl Clone for ExpandedSchema
Sourcefn clone(&self) -> ExpandedSchema
fn clone(&self) -> ExpandedSchema
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExpandedSchema
impl Debug for ExpandedSchema
Sourceimpl Default for ExpandedSchema
impl Default for ExpandedSchema
Sourcefn default() -> ExpandedSchema
fn default() -> ExpandedSchema
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ExpandedSchema
impl PartialEq for ExpandedSchema
Sourceimpl Serialize for ExpandedSchema
impl Serialize for ExpandedSchema
Sourceimpl TryFrom<ExpandedSchema> for LiftedSchema
impl TryFrom<ExpandedSchema> for LiftedSchema
Sourcetype Error = SchemaLiftError
type Error = SchemaLiftError
The type returned in the event of a conversion error.
Sourceimpl TryFrom<NormalizedSchema> for ExpandedSchema
impl TryFrom<NormalizedSchema> for ExpandedSchema
Sourcetype Error = SchemaExpandError
type Error = SchemaExpandError
The type returned in the event of a conversion error.
impl StructuralPartialEq for ExpandedSchema